Enum wasmi::Error[][src]

pub enum Error {
    Validation(String),
    Instantiation(String),
    Function(String),
    Table(String),
    Memory(String),
    Global(String),
    Value(String),
    Trap(Trap),
    Host(Box<dyn HostError>),
}
Internal interpreter error.

Variants

Validation(String)

Module validation error. Might occur only at load time.

Instantiation(String)

Error while instantiating a module. Might occur when provided with incorrect exports (i.e. linkage failure).

Function(String)

Function-level error.

Table(String)

Table-level error.

Memory(String)

Memory-level error.

Global(String)

Global-level error.

Value(String)

Value-level error.

Trap(Trap)

Trap.

Host(Box<dyn HostError>)

Custom embedder error.

Implementations

impl Error[src]

pub fn as_host_error(&self) -> Option<&dyn HostError>[src]

Returns a reference to a HostError if this Error represents some host error.

I.e. if this error have variant Host or Trap with host error.

pub fn into_host_error(self) -> Option<Box<dyn HostError>>[src]

Returns HostError if this Error represents some host error.

I.e. if this error have variant Host or Trap with host error.

pub fn try_into_host_error(self) -> Result<Box<dyn HostError>, Self>[src]

Returns HostError if this Error represents some host error, otherwise returns the original error.

I.e. if this error have variant Host or Trap with host error.