Enum wasmi::ExternVal [−][src]
An external value is the runtime representation of an entity that can be imported or exported.
Variants
Func(FuncRef)Table(TableRef)Memory(MemoryRef)Global(GlobalRef)Should be immutable.
Implementations
impl ExternVal[src]
impl ExternVal[src]pub fn as_func(&self) -> Option<&FuncRef>[src]
pub fn as_func(&self) -> Option<&FuncRef>[src]Get underlying function reference if this ExternVal contains
a function, or None if it is some other kind.
pub fn as_table(&self) -> Option<&TableRef>[src]
pub fn as_table(&self) -> Option<&TableRef>[src]Get underlying table reference if this ExternVal contains
a table, or None if it is some other kind.