pub enum MemoryError {
OutOfSystemMemory,
OutOfBoundsGrowth,
OutOfBoundsAccess,
InvalidMemoryType,
InvalidStaticBufferSize,
ResourceLimiterDeniedAllocation,
MinimumSizeOverflow,
MaximumSizeOverflow,
OutOfFuel {
required_fuel: u64,
},
}Expand description
An error that may occur upon operating with virtual or linear memory.
Variants
OutOfSystemMemory
Tried to allocate more virtual memory than technically possible.
OutOfBoundsGrowth
Tried to grow linear memory out of its set bounds.
OutOfBoundsAccess
Tried to access linear memory out of bounds.
InvalidMemoryType
Tried to create an invalid linear memory type.
InvalidStaticBufferSize
Tried to create memory with invalid static buffer size
ResourceLimiterDeniedAllocation
If a resource limiter denied allocation or growth of a linear memory.
MinimumSizeOverflow
The minimum size of the memory type overflows the system index type.
MaximumSizeOverflow
The maximum size of the memory type overflows the system index type.
OutOfFuel
Encountered if a memory.grow operation runs out of fuel.