Struct wasmi::MemoryRef [−][src]
pub struct MemoryRef(_);
Reference to a memory (See MemoryInstance for details).
This reference has a reference-counting semantics.
Methods from Deref<Target = MemoryInstance>
pub fn maximum(&self) -> Option<Pages>[src]
pub fn maximum(&self) -> Option<Pages>[src]Returns maximum amount of pages this MemoryInstance can grow to.
Returns None if there is no limit set.
Maximum memory size cannot exceed 65536 pages or 4GiB.
pub fn current_size(&self) -> Pages[src]
pub fn current_size(&self) -> Pages[src]Returns current linear memory size.
Maximum memory size cannot exceed 65536 pages or 4GiB.
Example
To convert number of pages to number of bytes you can use the following code:
use wasmi::MemoryInstance; use wasmi::memory_units::*; let memory = MemoryInstance::alloc(Pages(1), None).unwrap(); let byte_size: Bytes = memory.current_size().into(); assert_eq!( byte_size, Bytes(65536), );
pub fn get_value<T: LittleEndianConvert>(&self, offset: u32) -> Result<T, Error>[src]
pub fn get_value<T: LittleEndianConvert>(&self, offset: u32) -> Result<T, Error>[src]Get value from memory at given offset.
pub fn get(&self, offset: u32, size: usize) -> Result<Vec<u8>, Error>[src]
pub fn get(&self, offset: u32, size: usize) -> Result<Vec<u8>, Error>[src]Copy data from memory at given offset.
This will allocate vector for you.
If you can provide a mutable slice you can use get_into.
pub fn get_into(&self, offset: u32, target: &mut [u8]) -> Result<(), Error>[src]
pub fn get_into(&self, offset: u32, target: &mut [u8]) -> Result<(), Error>[src]Copy data from given offset in the memory into target slice.
Errors
Returns Err if the specified region is out of bounds.
pub fn set(&self, offset: u32, value: &[u8]) -> Result<(), Error>[src]
pub fn set(&self, offset: u32, value: &[u8]) -> Result<(), Error>[src]Copy data in the memory at given offset.
pub fn set_value<T: LittleEndianConvert>(
&self,
offset: u32,
value: T
) -> Result<(), Error>[src]
pub fn set_value<T: LittleEndianConvert>(
&self,
offset: u32,
value: T
) -> Result<(), Error>[src]Copy value in the memory at given offset.
pub fn grow(&self, additional: Pages) -> Result<Pages, Error>[src]
pub fn grow(&self, additional: Pages) -> Result<Pages, Error>[src]Increases the size of the linear memory by given number of pages. Returns previous memory size if succeeds.
Errors
Returns Err if attempted to allocate more memory than permited by the limit.
pub fn copy(
&self,
src_offset: usize,
dst_offset: usize,
len: usize
) -> Result<(), Error>[src]
pub fn copy(
&self,
src_offset: usize,
dst_offset: usize,
len: usize
) -> Result<(), Error>[src]Copy contents of one memory region to another.
Semantically equivalent to memmove.
Errors
Returns Err if either of specified regions is out of bounds.
pub fn copy_nonoverlapping(
&self,
src_offset: usize,
dst_offset: usize,
len: usize
) -> Result<(), Error>[src]
pub fn copy_nonoverlapping(
&self,
src_offset: usize,
dst_offset: usize,
len: usize
) -> Result<(), Error>[src]Copy contents of one memory region to another (non-overlapping version).
Semantically equivalent to memcpy.
but returns Error if source overlaping with destination.
Errors
Returns Err if:
- either of specified regions is out of bounds,
- these regions overlaps.
pub fn clear(&self, offset: usize, new_val: u8, len: usize) -> Result<(), Error>[src]
pub fn clear(&self, offset: usize, new_val: u8, len: usize) -> Result<(), Error>[src]Fill the memory region with the specified value.
Semantically equivalent to memset.
Errors
Returns Err if the specified region is out of bounds.
pub fn zero(&self, offset: usize, len: usize) -> Result<(), Error>[src]
pub fn zero(&self, offset: usize, len: usize) -> Result<(), Error>[src]Fill the specified memory region with zeroes.
Errors
Returns Err if the specified region is out of bounds.
pub fn erase(&self) -> Result<(), Error>[src]
pub fn erase(&self) -> Result<(), Error>[src]Set every byte in the entire linear memory to 0, preserving its size.
Might be useful for some optimization shenanigans.