Struct wasmi::StackRecycler [−][src]
pub struct StackRecycler { /* fields omitted */ }Expand description
Used to recycle stacks instead of allocating them repeatedly.
Implementations
impl StackRecycler[src]
impl StackRecycler[src]pub fn with_limits(value_stack_limit: usize, call_stack_limit: usize) -> Self[src]
pub fn with_limits(value_stack_limit: usize, call_stack_limit: usize) -> Self[src]Limit stacks created by this recycler to
value_stack_limitbytes for values andcall_stack_limitlevels for calls.
pub fn clear(&mut self)[src]
pub fn clear(&mut self)[src]Clears any values left on the stack to avoid leaking them to future export invocations.
This is a secondary defense to prevent modules from exploiting faulty stack handling in the interpreter.
Do note that there are additional channels that can leak information into an untrusted module.