AsContextMut

Trait AsContextMut 

pub trait AsContextMut: AsContext {
    // Required method
    fn as_context_mut(&mut self) -> StoreContextMut<'_, Self::Data>;
}
A trait used to get exclusive access to a Store in Wasmi.

Required Methods

fn as_context_mut(&mut self) -> StoreContextMut<'_, Self::Data>

Returns the store context that this type provides access to.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<T> AsContextMut for &mut T
where T: AsContextMut,

Implementors